@@ -45,8 +45,6 @@ void display_help(void)
 		 _("do not output any transfer information at all")},
 		{"-c", "--cursor", 0,
 		 _("use cursor positioning escape sequences")},
-		{"-L", "--rate-limit", _("RATE"),
-		 _("limit transfer to RATE bytes per second")},
 		{"-W", "--wait", 0,
 		 _("display nothing until first byte transferred")},
 		{"-s", "--size", _("SIZE"),
@@ -60,6 +58,11 @@ void display_help(void)
 		{"-N", "--name", _("NAME"),
 		 _("prefix visual information with NAME")},
 		{"", 0, 0, 0},
+		{"-L", "--rate-limit", _("RATE"),
+		 _("limit transfer to RATE bytes per second")},
+		{"-B", "--buffer-size", _("BYTES"),
+		 _("use a buffer size of BYTES")},
+		{"", 0, 0, 0},
 		{"-h", "--help", 0,
 		 _("show this help and exit")},
 		{"-l", "--license", 0,
