@@ -11,6 +11,8 @@
 #endif
 #include "options.h"
 
+/* #undef MAKE_STDOUT_NONBLOCKING */
+
 #include <unistd.h>
 #include <signal.h>
 #include <fcntl.h>
@@ -20,7 +22,7 @@
 #include <sys/time.h>
 
 
-void main_transfer_bufsize(unsigned long);
+void main_transfer_bufsize(unsigned long long, int);
 long main_transfer(opts_t, int, int *, int *, unsigned long long);
 void cursor_init(opts_t);
 void cursor_fini(opts_t);
@@ -104,10 +106,14 @@ static int main_loop(opts_t opts)
 		if (fd < 0)
 			return 1;
 		if (fstat64(fd, &sb) == 0) {
-			main_transfer_bufsize(sb.st_blksize * 32);
+			main_transfer_bufsize(sb.st_blksize * 32, 0);
 		}
 	}
 
+	if (opts->buffer_size > 0) {
+		main_transfer_bufsize(opts->buffer_size, 1);
+	}
+
 	while ((!(eof_in && eof_out)) || (!final_update)) {
 
 		tilreset = next_reset.tv_sec - cur_time.tv_sec;
@@ -337,11 +343,16 @@ int main(int argc, char **argv)
 	if (opts->height > 999999)
 		opts->height = 999999;
 
+#ifdef MAKE_STDOUT_NONBLOCKING
 	/*
 	 * Try and make standard output use non-blocking I/O.
+	 *
+	 * Note that this can cause problems with (broken) applications
+	 * such as dd.
 	 */
 	fcntl(STDOUT_FILENO, F_SETFL,
 	      O_NONBLOCK | fcntl(STDOUT_FILENO, F_GETFL));
+#endif				/* MAKE_STDOUT_NONBLOCKING */
 
 	/*
 	 * Set terminal option TOSTOP so we get signal SIGTTOU if we try to
